@@ -513,21 +513,25 @@ class TTClass(_TTClass):
             return _TTClass.__getattribute__(self, item)
 
 
-def def_pwd(path=None, change=True):
+def def_pwd(path=None, change=True,verbose=False):
     """try of get and define work path."""
     if path is None:
         path = os.getcwd()
-
+        pwd = path
     if os.path.exists(path):
+        path = os.path.abspath(path)
         if change:
             os.chdir(path)
+        pwd = os.getcwd()
     else:
         os.makedirs(path)
+        path = os.path.abspath(path)
         if change:
             os.chdir(path)
-    pwd = os.getcwd()
-    print("work path:", pwd)
-    print("checked path:", path)
+        pwd = os.getcwd()
+    if verbose:
+        print("work path:", pwd)
+        print("checked path:", path)
     locals()[pwd] = pwd
     return path
 
